@@ -26,10 +26,21 @@ class genetic_data_handler:
 
     def __init__(self):
 
-        self.subjects = np.ndarray
-        self.location = np.ndarray
 
-    def get_subject_id(self):
+        self.location = np.ndarray
+        self.chromosome= None
+
+        genetic_df = read_plink1_bin(genetic_data_path + "bed_files/" + "ukb22418_c" + "1" + "_b0_v2.bed",
+                                     genetic_data_path + "bim_files/" + "ukb_snp_chr" + "1" + "_v2.bim",
+                                     genetic_data_path + "fam_files/" + "ukb22418_c" + "1" + "_b0_v2_s488176.fam",
+                                     verbose=True)
+        genetic_df = genetic_df.set_index({"variant": "snp"})
+        self.subjects_list= genetic_df.sample.values
+
+
+
+
+    def get_subject_ids(self):
         """
         A utility function which lets user fetch numpy array containing the list of all subject ids
 
@@ -45,7 +56,7 @@ class genetic_data_handler:
             return None
 
         else:
-            return self.subjects
+            return self.subjects_list
 
     def get_all_genetic_data_storage_location(self):
         """
@@ -82,22 +93,24 @@ class genetic_data_handler:
             return self.location
 
 
-    def get_genetic_binary_data(self, chr_num):
-        """
-        A utility function which lets user fetch the genetic data associated with a chromosome number
 
-        Parameters:
-        a string representing a chromosome of interest
+    def set_chromosome_number(self,chr_num):
 
-        Returns:
-        categories list: pandas object having genetic data of a particular chromosome type
-        :rtype: pandas plink table
-        """
-        genetic_df = read_plink1_bin(genetic_data_path + "bed_files/" + "ukb22418_c" + chr_num + "_b0_v2.bed",
-                                     genetic_data_path + "bim_files/" + "ukb_snp_chr" + chr_num + "_v2.bim",
-                                     genetic_data_path + "fam_files/" + "ukb22418_c" + chr_num + "_b0_v2_s488176.fam",
-                                     verbose=True)
+        self.chromosome=chr_num
+        print("Genetic handler object initialized with chromosome")
 
-        self.subjects = genetic_df.sample.values
-        self.location = genetic_df.pos.values
-        return genetic_df
+    def get_binary_data(self, subject_list):
+        genetic_data_output = []
+        for chr_num in ["1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13"]:
+
+            genetic_df = read_plink1_bin(genetic_data_path + "bed_files/" + "ukb22418_c" + chr_num + "_b0_v2.bed",
+                                         genetic_data_path + "bim_files/" + "ukb_snp_chr" + chr_num + "_v2.bim",
+                                         genetic_data_path + "fam_files/" + "ukb22418_c" + chr_num + "_b0_v2_s488176.fam",verbose=True)
+            genetic_df = genetic_df.set_index({"variant": "snp"})
+            temp_output = genetic_df.sel(sample=subject_list).values
+            genetic_data_output.append(temp_output)
+
+            del genetic_df
+            del temp_output
+
+        return genetic_data_output
